"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SessionAuthDetailProvider = void 0;
const signer_1 = require("../signer");
const http_1 = require("../http");
const request_generator_1 = require("../request-generator");
const config_file_auth_1 = require("./config-file-auth");
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const helper_1 = require("../helper");
class SessionAuthDetailProvider extends config_file_auth_1.ConfigFileAuthenticationDetailsProvider {
    constructor(configurationFilePath, profile) {
        super(configurationFilePath, profile);
        this.skipRefresh = false;
    }
    getKeyId() {
        return __awaiter(this, void 0, void 0, function* () {
            return "ST$" + (yield this.getSecurityToken());
        });
    }
    getSecurityToken() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.isValidSessionToken() || this.skipRefresh) {
                return this.sessionToken;
            }
            return yield this.refreshSessionToken();
        });
    }
    isValidSessionToken() {
        let jwt = null;
        try {
            const secondsSinceEpoch = Math.round(Date.now() / 1000);
            jwt = jsonwebtoken_1.default.decode(this.sessionToken, { complete: true });
            if (jwt == null) {
                return false;
            }
            else if (jwt.payload && jwt.payload.exp > secondsSinceEpoch) {
                return true;
            }
            return false;
        }
        catch (e) {
            throw Error(`Failed to decode token, error: ${e}`);
        }
    }
    refreshSessionToken() {
        return __awaiter(this, void 0, void 0, function* () {
            this.skipRefresh = true; // avoid infinite loop on calling refreshSessionToken()
            try {
                const signer = new signer_1.DefaultRequestSigner(this);
                const client = new http_1.FetchHttpClient(signer);
                const region = this.getRegion().regionId;
                const request = yield request_generator_1.composeRequest({
                    baseEndpoint: `https://auth.${region}.oraclecloud.com`,
                    path: `/v1/authentication/refresh`,
                    method: "POST",
                    defaultHeaders: { "content-type": "application/json" },
                    bodyContent: JSON.stringify({ currentToken: this.sessionToken })
                });
                const response = yield client.send(request);
                this.skipRefresh = false;
                if (response.status === 200) {
                    const tokenJson = yield response.json();
                    const tokenStr = tokenJson.token;
                    this.sessionToken = tokenStr;
                    return this.sessionToken;
                }
                else if (response.status === 401) {
                    const errBody = yield helper_1.handleErrorBody(response);
                    throw new Error(`Authentication Error calling Identity to refresh token. Error: ${JSON.stringify(errBody)}`);
                }
                else {
                    const errBody = yield helper_1.handleErrorBody(response);
                    throw new Error(`Token cannot be refreshed. Error: ${JSON.stringify(errBody)}`);
                }
            }
            catch (e) {
                this.skipRefresh = false;
                throw new Error(`Failed to refresh the session token due to ${e}`);
            }
        });
    }
}
exports.SessionAuthDetailProvider = SessionAuthDetailProvider;
//# sourceMappingURL=session-auth-details-provider.js.map