/**
 * Java Management Service API
 * API for the Java Management Service. Use this API to view, create, and manage Fleets.
 * OpenAPI spec version: 20210610
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2023, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { JavaManagementServiceWaiter } from "./javamanagementservice-waiter";
export declare enum JavaManagementServiceApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class JavaManagementServiceClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": JavaManagementServiceWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpOptions: any;
    targetService: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new JavaManagementServiceWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): JavaManagementServiceWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): JavaManagementServiceWaiter;
    /**
     * Add Java installation sites in a Fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AddFleetInstallationSitesRequest
     * @return AddFleetInstallationSitesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/AddFleetInstallationSites.ts.html |here} to see how to use AddFleetInstallationSites API.
     */
    addFleetInstallationSites(addFleetInstallationSitesRequest: requests.AddFleetInstallationSitesRequest): Promise<responses.AddFleetInstallationSitesResponse>;
    /**
     * Deletes the work request specified by an identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelWorkRequestRequest
     * @return CancelWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/CancelWorkRequest.ts.html |here} to see how to use CancelWorkRequest API.
     */
    cancelWorkRequest(cancelWorkRequestRequest: requests.CancelWorkRequestRequest): Promise<responses.CancelWorkRequestResponse>;
    /**
     * Move a specified Fleet into the compartment identified in the POST form. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeFleetCompartmentRequest
     * @return ChangeFleetCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/ChangeFleetCompartment.ts.html |here} to see how to use ChangeFleetCompartment API.
     */
    changeFleetCompartment(changeFleetCompartmentRequest: requests.ChangeFleetCompartmentRequest): Promise<responses.ChangeFleetCompartmentResponse>;
    /**
     * Add a new record to the fleet blocklist.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateBlocklistRequest
     * @return CreateBlocklistResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/CreateBlocklist.ts.html |here} to see how to use CreateBlocklist API.
     */
    createBlocklist(createBlocklistRequest: requests.CreateBlocklistRequest): Promise<responses.CreateBlocklistResponse>;
    /**
       * Create a new Fleet using the information provided.
  * <p>
  `inventoryLog` is now a required parameter for CreateFleet API.
  * Update existing applications using this API
  * before July 15, 2022 to ensure the applications continue to work.
  * See the [Service Change Notice](https://docs.oracle.com/en-us/iaas/Content/servicechanges.htm#JMS) for more details.
  * Migrate existing fleets using the `UpdateFleet` API to set the `inventoryLog` parameter.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param CreateFleetRequest
       * @return CreateFleetResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/CreateFleet.ts.html |here} to see how to use CreateFleet API.
       */
    createFleet(createFleetRequest: requests.CreateFleetRequest): Promise<responses.CreateFleetResponse>;
    /**
     * Deletes the blocklist record specified by an identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteBlocklistRequest
     * @return DeleteBlocklistResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/DeleteBlocklist.ts.html |here} to see how to use DeleteBlocklist API.
     */
    deleteBlocklist(deleteBlocklistRequest: requests.DeleteBlocklistRequest): Promise<responses.DeleteBlocklistResponse>;
    /**
     * Deletes only the metadata of the Crypto Event Analysis result, but the file remains in the object storage.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteCryptoAnalysisResultRequest
     * @return DeleteCryptoAnalysisResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/DeleteCryptoAnalysisResult.ts.html |here} to see how to use DeleteCryptoAnalysisResult API.
     */
    deleteCryptoAnalysisResult(deleteCryptoAnalysisResultRequest: requests.DeleteCryptoAnalysisResultRequest): Promise<responses.DeleteCryptoAnalysisResultResponse>;
    /**
     * Deletes the Fleet specified by an identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteFleetRequest
     * @return DeleteFleetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/DeleteFleet.ts.html |here} to see how to use DeleteFleet API.
     */
    deleteFleet(deleteFleetRequest: requests.DeleteFleetRequest): Promise<responses.DeleteFleetResponse>;
    /**
     * Generates Agent Deploy Script for Fleet using the information provided.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GenerateAgentDeployScriptRequest
     * @return GenerateAgentDeployScriptResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/GenerateAgentDeployScript.ts.html |here} to see how to use GenerateAgentDeployScript API.
     */
    generateAgentDeployScript(generateAgentDeployScriptRequest: requests.GenerateAgentDeployScriptRequest): Promise<responses.GenerateAgentDeployScriptResponse>;
    /**
     * Retrieve metadata of the Crypto Event Analysis result.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetCryptoAnalysisResultRequest
     * @return GetCryptoAnalysisResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/GetCryptoAnalysisResult.ts.html |here} to see how to use GetCryptoAnalysisResult API.
     */
    getCryptoAnalysisResult(getCryptoAnalysisResultRequest: requests.GetCryptoAnalysisResultRequest): Promise<responses.GetCryptoAnalysisResultResponse>;
    /**
     * Retrieve a Fleet with the specified identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFleetRequest
     * @return GetFleetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/GetFleet.ts.html |here} to see how to use GetFleet API.
     */
    getFleet(getFleetRequest: requests.GetFleetRequest): Promise<responses.GetFleetResponse>;
    /**
     * Returns fleet level advanced feature configuration
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFleetAdvancedFeatureConfigurationRequest
     * @return GetFleetAdvancedFeatureConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/GetFleetAdvancedFeatureConfiguration.ts.html |here} to see how to use GetFleetAdvancedFeatureConfiguration API.
     */
    getFleetAdvancedFeatureConfiguration(getFleetAdvancedFeatureConfigurationRequest: requests.GetFleetAdvancedFeatureConfigurationRequest): Promise<responses.GetFleetAdvancedFeatureConfigurationResponse>;
    /**
     * Retrieve a Fleet Agent Configuration for the specified Fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFleetAgentConfigurationRequest
     * @return GetFleetAgentConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/GetFleetAgentConfiguration.ts.html |here} to see how to use GetFleetAgentConfiguration API.
     */
    getFleetAgentConfiguration(getFleetAgentConfigurationRequest: requests.GetFleetAgentConfigurationRequest): Promise<responses.GetFleetAgentConfigurationResponse>;
    /**
     * Returns metadata associated with a specific Java release family.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJavaFamilyRequest
     * @return GetJavaFamilyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/GetJavaFamily.ts.html |here} to see how to use GetJavaFamily API.
     */
    getJavaFamily(getJavaFamilyRequest: requests.GetJavaFamilyRequest): Promise<responses.GetJavaFamilyResponse>;
    /**
     * Returns detail of a Java release.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJavaReleaseRequest
     * @return GetJavaReleaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/GetJavaRelease.ts.html |here} to see how to use GetJavaRelease API.
     */
    getJavaRelease(getJavaReleaseRequest: requests.GetJavaReleaseRequest): Promise<responses.GetJavaReleaseResponse>;
    /**
     * Retrieve the details of a work request with the specified ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a list of blocklist entities contained by a fleet.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListBlocklistsRequest
     * @return ListBlocklistsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/ListBlocklists.ts.html |here} to see how to use ListBlocklists API.
     */
    listBlocklists(listBlocklistsRequest: requests.ListBlocklistsRequest): Promise<responses.ListBlocklistsResponse>;
    /**
     * List Crypto Event Analysis results.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListCryptoAnalysisResultsRequest
     * @return ListCryptoAnalysisResultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/ListCryptoAnalysisResults.ts.html |here} to see how to use ListCryptoAnalysisResults API.
     */
    listCryptoAnalysisResults(listCryptoAnalysisResultsRequest: requests.ListCryptoAnalysisResultsRequest): Promise<responses.ListCryptoAnalysisResultsResponse>;
    /**
     * Returns a list of all the Fleets contained by a compartment. The query parameter `compartmentId`
     * is required unless the query parameter `id` is specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFleetsRequest
     * @return ListFleetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/ListFleets.ts.html |here} to see how to use ListFleets API.
     */
    listFleets(listFleetsRequest: requests.ListFleetsRequest): Promise<responses.ListFleetsResponse>;
    /**
     * List Java installation sites in a Fleet filtered by query parameters.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListInstallationSitesRequest
     * @return ListInstallationSitesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/ListInstallationSites.ts.html |here} to see how to use ListInstallationSites API.
     */
    listInstallationSites(listInstallationSitesRequest: requests.ListInstallationSitesRequest): Promise<responses.ListInstallationSitesResponse>;
    /**
     * Returns a list of the Java release family information.
     * A Java release family is typically a major version in the Java version identifier.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJavaFamiliesRequest
     * @return ListJavaFamiliesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/ListJavaFamilies.ts.html |here} to see how to use ListJavaFamilies API.
     */
    listJavaFamilies(listJavaFamiliesRequest: requests.ListJavaFamiliesRequest): Promise<responses.ListJavaFamiliesResponse>;
    /**
     * Returns a list of Java releases.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJavaReleasesRequest
     * @return ListJavaReleasesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/ListJavaReleases.ts.html |here} to see how to use ListJavaReleases API.
     */
    listJavaReleases(listJavaReleasesRequest: requests.ListJavaReleasesRequest): Promise<responses.ListJavaReleasesResponse>;
    /**
     * List Java Runtime usage in a specified host filtered by query parameters.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJreUsageRequest
     * @return ListJreUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/ListJreUsage.ts.html |here} to see how to use ListJreUsage API.
     */
    listJreUsage(listJreUsageRequest: requests.ListJreUsageRequest): Promise<responses.ListJreUsageResponse>;
    /**
     * Retrieve a (paginated) list of work items for a specified work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkItemsRequest
     * @return ListWorkItemsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/ListWorkItems.ts.html |here} to see how to use ListWorkItems API.
     */
    listWorkItems(listWorkItemsRequest: requests.ListWorkItemsRequest): Promise<responses.ListWorkItemsResponse>;
    /**
     * Retrieve a (paginated) list of errors for a specified work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Retrieve a (paginated) list of logs for a specified work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * List the work requests in a compartment. The query parameter `compartmentId` is required unless the query parameter `id` or `fleetId` is specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Remove Java installation sites in a Fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RemoveFleetInstallationSitesRequest
     * @return RemoveFleetInstallationSitesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/RemoveFleetInstallationSites.ts.html |here} to see how to use RemoveFleetInstallationSites API.
     */
    removeFleetInstallationSites(removeFleetInstallationSitesRequest: requests.RemoveFleetInstallationSitesRequest): Promise<responses.RemoveFleetInstallationSitesResponse>;
    /**
     * Request to perform crypto analyses. The result of crypto analysis will be uploaded to the
     * object storage bucket desiginated when enable Crypto Event Analysis feature.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RequestCryptoAnalysesRequest
     * @return RequestCryptoAnalysesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/RequestCryptoAnalyses.ts.html |here} to see how to use RequestCryptoAnalyses API.
     */
    requestCryptoAnalyses(requestCryptoAnalysesRequest: requests.RequestCryptoAnalysesRequest): Promise<responses.RequestCryptoAnalysesResponse>;
    /**
     * Request to collect the JFR recordings on the selected target. The JFR files are uploaded
     * to the object storage bucket that you designated when you enabled the recording feature.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RequestJfrRecordingsRequest
     * @return RequestJfrRecordingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/RequestJfrRecordings.ts.html |here} to see how to use RequestJfrRecordings API.
     */
    requestJfrRecordings(requestJfrRecordingsRequest: requests.RequestJfrRecordingsRequest): Promise<responses.RequestJfrRecordingsResponse>;
    /**
     * Scan Java server usage in a fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ScanJavaServerUsageRequest
     * @return ScanJavaServerUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/ScanJavaServerUsage.ts.html |here} to see how to use ScanJavaServerUsage API.
     */
    scanJavaServerUsage(scanJavaServerUsageRequest: requests.ScanJavaServerUsageRequest): Promise<responses.ScanJavaServerUsageResponse>;
    /**
     * Scan library usage in a fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ScanLibraryUsageRequest
     * @return ScanLibraryUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/ScanLibraryUsage.ts.html |here} to see how to use ScanLibraryUsage API.
     */
    scanLibraryUsage(scanLibraryUsageRequest: requests.ScanLibraryUsageRequest): Promise<responses.ScanLibraryUsageResponse>;
    /**
     * List application usage in a Fleet filtered by query parameters.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeApplicationUsageRequest
     * @return SummarizeApplicationUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/SummarizeApplicationUsage.ts.html |here} to see how to use SummarizeApplicationUsage API.
     */
    summarizeApplicationUsage(summarizeApplicationUsageRequest: requests.SummarizeApplicationUsageRequest): Promise<responses.SummarizeApplicationUsageResponse>;
    /**
     * List deployed applications in a fleet filtered by query parameters.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeDeployedApplicationUsageRequest
     * @return SummarizeDeployedApplicationUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/SummarizeDeployedApplicationUsage.ts.html |here} to see how to use SummarizeDeployedApplicationUsage API.
     */
    summarizeDeployedApplicationUsage(summarizeDeployedApplicationUsageRequest: requests.SummarizeDeployedApplicationUsageRequest): Promise<responses.SummarizeDeployedApplicationUsageResponse>;
    /**
     * List Java installation usage in a Fleet filtered by query parameters.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeInstallationUsageRequest
     * @return SummarizeInstallationUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/SummarizeInstallationUsage.ts.html |here} to see how to use SummarizeInstallationUsage API.
     */
    summarizeInstallationUsage(summarizeInstallationUsageRequest: requests.SummarizeInstallationUsageRequest): Promise<responses.SummarizeInstallationUsageResponse>;
    /**
     * List Java server instances in a fleet filtered by query parameters.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeJavaServerInstanceUsageRequest
     * @return SummarizeJavaServerInstanceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/SummarizeJavaServerInstanceUsage.ts.html |here} to see how to use SummarizeJavaServerInstanceUsage API.
     */
    summarizeJavaServerInstanceUsage(summarizeJavaServerInstanceUsageRequest: requests.SummarizeJavaServerInstanceUsageRequest): Promise<responses.SummarizeJavaServerInstanceUsageResponse>;
    /**
     * List Java servers in a fleet filtered by query parameters.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeJavaServerUsageRequest
     * @return SummarizeJavaServerUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/SummarizeJavaServerUsage.ts.html |here} to see how to use SummarizeJavaServerUsage API.
     */
    summarizeJavaServerUsage(summarizeJavaServerUsageRequest: requests.SummarizeJavaServerUsageRequest): Promise<responses.SummarizeJavaServerUsageResponse>;
    /**
     * List Java Runtime usage in a specified Fleet filtered by query parameters.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeJreUsageRequest
     * @return SummarizeJreUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/SummarizeJreUsage.ts.html |here} to see how to use SummarizeJreUsage API.
     */
    summarizeJreUsage(summarizeJreUsageRequest: requests.SummarizeJreUsageRequest): Promise<responses.SummarizeJreUsageResponse>;
    /**
     * List libraries in a fleet filtered by query parameters.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeLibraryUsageRequest
     * @return SummarizeLibraryUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/SummarizeLibraryUsage.ts.html |here} to see how to use SummarizeLibraryUsage API.
     */
    summarizeLibraryUsage(summarizeLibraryUsageRequest: requests.SummarizeLibraryUsageRequest): Promise<responses.SummarizeLibraryUsageResponse>;
    /**
     * List managed instance usage in a Fleet filtered by query parameters.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeManagedInstanceUsageRequest
     * @return SummarizeManagedInstanceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/SummarizeManagedInstanceUsage.ts.html |here} to see how to use SummarizeManagedInstanceUsage API.
     */
    summarizeManagedInstanceUsage(summarizeManagedInstanceUsageRequest: requests.SummarizeManagedInstanceUsageRequest): Promise<responses.SummarizeManagedInstanceUsageResponse>;
    /**
     * Retrieve the inventory of JMS resources in the specified compartment: a list of the number of _active_ fleets, managed instances, Java Runtimes, Java installations, and applications.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeResourceInventoryRequest
     * @return SummarizeResourceInventoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/SummarizeResourceInventory.ts.html |here} to see how to use SummarizeResourceInventory API.
     */
    summarizeResourceInventory(summarizeResourceInventoryRequest: requests.SummarizeResourceInventoryRequest): Promise<responses.SummarizeResourceInventoryResponse>;
    /**
     * Update the Fleet specified by an identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateFleetRequest
     * @return UpdateFleetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/UpdateFleet.ts.html |here} to see how to use UpdateFleet API.
     */
    updateFleet(updateFleetRequest: requests.UpdateFleetRequest): Promise<responses.UpdateFleetResponse>;
    /**
     * Update advanced feature configurations for the fleet
     * Ensure that the namespace and bucket storage are created prior to turning on the JfrRecording or CryptoEventAnalysis feature
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateFleetAdvancedFeatureConfigurationRequest
     * @return UpdateFleetAdvancedFeatureConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/UpdateFleetAdvancedFeatureConfiguration.ts.html |here} to see how to use UpdateFleetAdvancedFeatureConfiguration API.
     */
    updateFleetAdvancedFeatureConfiguration(updateFleetAdvancedFeatureConfigurationRequest: requests.UpdateFleetAdvancedFeatureConfigurationRequest): Promise<responses.UpdateFleetAdvancedFeatureConfigurationResponse>;
    /**
     * Update the Fleet Agent Configuration for the specified Fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateFleetAgentConfigurationRequest
     * @return UpdateFleetAgentConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.53.0/jms/UpdateFleetAgentConfiguration.ts.html |here} to see how to use UpdateFleetAgentConfiguration API.
     */
    updateFleetAgentConfiguration(updateFleetAgentConfigurationRequest: requests.UpdateFleetAgentConfigurationRequest): Promise<responses.UpdateFleetAgentConfigurationResponse>;
}
